@@ -10,20 +10,9 @@
 #############################################################
 import mb_cgi
 
-class BanksConfig(mb_cgi.JSONCGI):
-    """
-    This class generates the databanks configuration that needs to be known by the client to build databoxes
-    
-    @author: Herve Menager
-    @organization: Institut Pasteur
-    @contact:mobyle@pasteur.fr
-    """
-    
-    def process( self ):
-      bc = self.cfg.getDatabanksConfig()
-      self.jsonMap = bc
+def process( self ):
+    bc = self.cfg.getDatabanksConfig()
+    self.jsonMap = bc
 
 if __name__ == "__main__":
-    bc = BanksConfig()
-    bc.process()
-    bc.render()
\ No newline at end of file
+    mb_cgi.JSONCGI(processFunction=process)
\ No newline at end of file
